<?php
/**
 * This is the phpNSTAClient configuration file.
 * Please be careful when you change something in this file
 */

/**
 * Copyright (C) 2005-2015 it-novum GmbH
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License version 2 as published 
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
 * See the GNU General Public License for more details.
 **/
$config = array(
	/**
	 * phpNSTAClient main configuration
	 **/
	'MAIN' => array(
		/**
		 * version
		 * Current version of phpNSTAClient
		 * Type: String
		 * @since 1.0
		 * @version 1.11.0
		 **/
		'version' => '1.11.0',
		
		
		/**
		 * pid_file
		 * Path to phpNSTAClient's PID file
		 * Type: String
		 * @since 1.0
		 * @version 1.5
		 **/
		'pid_file' => '/var/run/phpNSTAClient.pid',
	),
	
	
	/**
	 * Global logging settings
	 **/
	'LOG' => array(
		/**
		 * logfile
		 * Path to the phpNSTAClient logfile
		 * Type: String
		 * @since 1.0
		 **/
		'logfile' => '/var/log/phpNSTAClient.log',
		
		
		/**
		 * loglevel
		 * -1 disable loging
		 * 0 only some information about phpNSTAClient
		 * 1 Nagios process information
		 * 2 Gearman information
		 * 3 ALL
		 * Type: Integer
		 * @since 1.0
		 **/
		'loglevel' => 3,
		
		
		/**
		 * logrotate
		 * Whether a logrotate should run
		 * Type: Boolean
		 * true = On
		 * false = off
		 * @since 1.0
		 **/
		'logrotate' => true,
		
		
		/**
		 * logrotate
		 * Time for Logratoe
		 * Type: Time (HH:MM)
		 * Example: 00:00 => midnight
		 * Example: 10:00 => 10 o'Clock AM
		 * Example: 15:00 => 3 o'Clock  PM
		 * @since 1.0
		 **/
		'logrotate_time' => '00:00',
		
		
		/**
		* logrotate_path
		* Path where the zip-Archiv of the logrotae will be saved
		* Type: String
		* @since 1.0
		**/
		'logrotate_path' => '/var/log/',
		
		
		/**
		* logrotate_date_format
		* Sufix for the *.zip File from logrotate
		* Type: PHP Date-Format (String)
		* Example Germany: 'd_m_Y_H_i' => 31_12_2013_15_30  
		* Example USA: 'm_d_Y_H_i' => 12_31_2013_15_30
		* @since 1.0
		**/
		'logrotate_date_format' => 'd_m_Y_H_i',
		
		
		/**
		 * date_format
		 * Describes the appearance of the date
		 * Type: PHP Date-Format (String)
		 * Example Germany: 'd.m.Y H:i:s' => 31.12.2013 15:30:59  
		 * Example USA: 'm.d.Y H:i:s' => 12.31.2013 15:30:59
		 * @since 1.0
		 **/
		'date_format' => 'd.m.Y H:i:s',
		
		/**
		* cleanup_logfile
		* Delete old logfile in the logrotate_path
		* Type: Boolean
		* true = on
		* false = off
		* @since 1.2
		**/
		'cleanup_logfile' => true,
		
		/**
		* cleanup_fileage
		* Delete all logfiles from phpNSTA that are older than n days
		* Type: Integer
		* Value in Days
		* @example 10
		* @since 1.2
		**/
		'cleanup_fileage' => 3,
	),
	
	
	/**
	 * Global Nagios settings
	 **/
	'NAGIOS' => array(

		/**
		 * cmd_file
		 * Path to the nagios command file (nagios.cmd)
		 * Type: String
		 * @since 1.0
		 **/
		'nagios_cmd' => '/opt/openitc/nagios/var/rw/nagios.cmd',

		/**
		* max_age
		* Time in seconds phpNSTACleint_Trigger will force the master system to process the cached data
		* Type: Integer
		* Default: 10
		* @since 1.3
		* @deprecated DEPRECATED Value! May be removed in future versions!
		**/
		'max_age' => 10,
	),
	
	
	/**
	 * Global Gearman settings
	 **/
	'GEARMAN' => array(
		/**
		 * localhost
		 * FQDN or IP Address of the local Gearman Job Server
		 * Type: String
		 * @since 1.0
		 **/
		'host' => '127.0.0.1',
		
		
		/**
		 * port
		 * TCP port on which the Gearman server on the local system listens
		 * Type: Integer
		 * @since 1.0
		 **/
		'port' => 4730,
		
		/**
		* timeout
		* Connection timeout milliseconds
		* Type: Integer
		* Default: 1000
		* @since 1.1
		**/
		'timeout' => 1000,
		
		
		/**
		 * use_initscript
		 * Use the Gearman Job Servers init Script to restart Gearman or not
		 * Type: Boolean
		 * @since 1.4
		 * @version 1.5
		 **/
		'use_initscript' => true,
		
		/**
		 * binary
		 * Path to the germand binary
		 * Type: String
		 * @since 1.0
		 **/
		'binary' => '/usr/local/sbin/gearmand',
		
		
		/**
		 * start_parameters
		 * The Command parameters for starting the Gearman Job Server
		 * Type: String
		 * @since 1.0
		 **/
		'start_parameters' => ' -d -L ',
		
		
		/**
		 * interface
		 * The IP address of an interface the Gearman Job Server will bind to
		 * Type: String
		 * @since 1.0
		 **/
		'interface' => '0.0.0.0',
		
		/**
		 * bulk_transmit
		 * Determine if phpNSTAClient will create packages of multiple check results for the master
		 * Enable this if you have a high network latency e.g Europe -> USA or Europe -> Asia
		 * Type: Boolean
		 * Default: true
		 * @since 1.6
		 **/
		'bulk_transmit' => true,
		
		/**
		 * bulk_limit
		 * Determine how many check results will be compressed to one package
		 * Type: Integer
		 * Default: 200
		 * @since 1.6
		 **/
		'bulk_limit' => 200,
		
		/**
		 * bulk_timeout
		 * Determine how many seconds, phpNSTAClient will wait until bulk_limit is reached
		 * Type: Integer
		 * Default: 10
		 * @since 1.6
		 **/
		'bulk_timeout' => 10,
		
		/**
		 * compression
		 * compression algorithm which should be used if bulk_transmit is true
		 * Values: auto, gz, bz2
		 * Type: String
		 * Default: auto
		 * @since 1.6
		 **/
		'compression' => 'auto',
	)
);
