<?php
/**
 * Copyright (C) 2005-2017 it-novum GmbH
 *
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License version 2 as published 
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
 * See the GNU General Public License for more details.
 **/

class Bulk{
	
	private $compression = false;
	
	private $bulkTimeout = 10;
	private $bulkLimit = 200;
	
	private $HostCacheAge = 0;
	private $HostResultCache = array();
	
	private $ServiceCacheAge = 0;
	private $ServiceResultCache = array();
	
	private $CustomCacheAge = 0;
	private $CustomDataCache = array();
	
	public function __construct($compression = false){
		$this->compression = $compression;
		$this->bulkTimeout = (int)Config::val('GEARMAN', 'bulk_timeout');
		$this->bulkLimit = (int)Config::val('GEARMAN', 'bulk_limit');
		
		$this->HostCacheAge = time();
		$this->ServiceCacheAge = time();
	}
	
	public function flushRequiredForHosts(){
		if(((time() - $this->HostCacheAge) > $this->bulkTimeout) || sizeof($this->HostResultCache) >= $this->bulkLimit){
			$this->HostCacheAge = time();
			if(!empty($this->HostResultCache)){
				return true;
			}
		}
		return false;
	}
	
	public function flushRequiredForServices(){
		if(((time() - $this->ServiceCacheAge) > $this->bulkTimeout) || sizeof($this->ServiceResultCache) >= $this->bulkLimit){
			$this->ServiceCacheAge = time();
			if(!empty($this->ServiceResultCache)){
				return true;
			}
		}
		return false;
	}
	
	public function flushRequiredForCustomData(){
		if(((time() - $this->CustomCacheAge) > $this->bulkTimeout) || sizeof($this->CustomDataCache) >= $this->bulkLimit){
			$this->CustomCacheAge = time();
			if(!empty($this->CustomDataCache)){
				return true;
			}
		}
		return false;
	}
	
	public function flushHosts(){
		if(!empty($this->HostResultCache)){
			$this->flush($this->HostResultCache, 'ochp_bulk');
		}
		$this->HostResultCache = array();
		$this->HostCacheAge = time();
	}
	
	public function flushServices(){
		if(!empty($this->ServiceResultCache)){
			$this->flush($this->ServiceResultCache, 'ocsp_bulk');
		}
		$this->ServiceResultCache = array();
		$this->ServiceCacheAge = time();
	}
	
	public function flushCustom(){
		if(!empty($this->CustomDataCache)){
			$this->flushUncompressed($this->CustomDataCache, 'phpnsta_custom_bulk');
		}
		$this->CustomDataCache = array();
		$this->CustomCacheAge = time();
	}
	
	private function flush($BulkResultCache, $queueName){
		$GearmanClient = new GearmanClient();
		$GearmanClient->setTimeout(Config::val('GEARMAN', 'timeout'));
		$GearmanClient->addServer(Config::val('GEARMAN', 'host'), Config::val('GEARMAN', 'port'));

		Logger::log('Flush '.sizeof($BulkResultCache).' records to '.$queueName.' queue', 2);
		$data = serialize($BulkResultCache);
		if($this->compression == 'gz'){
			$data = gzcompress($data, 6);
		}
		if($this->compression == 'bz2'){
			$data = bzcompress($data, 6);
		}
		
		
		$GearmanClient->doBackground($queueName, serialize(array(
			'compression' => $this->compression,
			'data' => $data
		)));
		unset($GearmanClient);
	}
	
	private function flushUncompressed($BulkResultCache, $queueName){
		$GearmanClient = new GearmanClient();
		$GearmanClient->setTimeout(Config::val('GEARMAN', 'timeout'));
		$GearmanClient->addServer(Config::val('GEARMAN', 'host'), Config::val('GEARMAN', 'port'));

		$count = sizeof($BulkResultCache);

		Logger::log('Flush '.$count.' records uncompressed to '.$queueName.' queue', 2);
		
		$data = array(
			'count' => $count,
			'timestamp' => time(),
			'data' => $BulkResultCache
		);
		
		
		$GearmanClient->doBackground($queueName, json_encode(
			$data
		));
		unset($GearmanClient);
	}

	
	public function addHostRecord($data){
		//$this->HostCacheAge = time();
		$this->HostResultCache[] = $data;
	}
	
	
	public function addServiceRecord($data){
		//$this->ServiceCacheAge = time();
		$this->ServiceResultCache[] = $data;
	}
	
	public function addCustomRecord($data){
		//$this->CustomCacheAge = time();
		$this->CustomDataCache[] = $data;
	}
	
}
