<?php
/**
 * phpNSTAClient
 *
 * This file is part of the phpNSTAClient
 *
 * @license http://www.gnu.de/documents/gpl-2.0.de.html
 * @copyright 2013 - 2016
 */

require_once "static.class.config.php";
require_once "static.class.log.php";
require_once "class.cli.php";
require_once "bulk.class.php";

ini_set('error_log', Config::val('LOG', 'logfile'));

/**
 * Function: bootup
 *
 * Führt alle, für den Start des phpNSTAClient wichtigen Routinen aus.
 * Gibt des weiteren nützliche Informationen dem Benutzer aus.
 *
 * @return void
 * @package phpNSTAClient
 * @author Daniel Ziegler <daniel.ziegler@it-novum.com>
 * @since 1.0
 *
 */
function bootup(){
	$CLI = new CLI();
	Logger::welcome();
	$CLI->echoWelcome();
	if(!checkPID()){
		$CLI->_echo('Finished daemonizing... [My PID = '.getmypid().']', 'green');
		Logger::log('Finished daemonizing... [My PID = '.getmypid().']', 0);
		createPID();
	}else{
		$CLI->_echo('ERROR! PID FILE '.Config::val('MAIN', 'pid_file').' already exists! I will die now!', 'red');
		Logger::log('ERROR! PID FILE '.Config::val('MAIN', 'pid_file').' already exists! I will die now!', 0);
		exit(3);
	}
}


/**
 * Function: checkPID
 *
 * Prüft ob das PID-File des phpNSTAClient bereits existiert
 *
 * @return Boolean
 * @package phpNSTAClient
 * @author Daniel Ziegler <daniel.ziegler@it-novum.com>
 * @since 1.0
 *
 */
function checkPID(){
	if(file_exists(Config::val('MAIN', 'pid_file'))){
		return true;
	}
	
	return false;
}

/**
 * Function: createPID
 *
 * Erstellt das PID-File des phpNSTAClient und füllt es mit der aktuellen PID des Parent-Prozesses
 *
 * @return void
 * @package phpNSTAClient
 * @author Daniel Ziegler <daniel.ziegler@it-novum.com>
 * @since 1.0
 *
 */
function createPID(){
	$file = fopen(Config::val('MAIN', 'pid_file'), 'w+');
	fwrite($file, getmypid());
	fclose($file);
}

/**
 * Function: deletePID
 *
 * Prüft ob das PID-File existiert und löscht es anschließend
 *
 * @return void
 * @package phpNSTAClient
 * @author Daniel Ziegler <daniel.ziegler@it-novum.com>
 * @since 1.0
 *
 */
function deletePID(){
	if(file_exists(Config::val('MAIN', 'pid_file'))){
		unlink(Config::val('MAIN', 'pid_file'));
	}
}

/**
 * Function: selfTest
 *
 * Führt einen Selbstest aus, und prüft ob wichtige Dateien existieren und beschreibbar sind.
 *
 * @return Boolean
 * @package phpNSTAClient
 * @author Daniel Ziegler <daniel.ziegler@it-novum.com>
 * @since 1.0
 *
 */
function selfTest(){
	$error = false;
	$CLI = new CLI();
	
	if($error === true){
		$CLI->_echo("ERROR: Pre-flight check not passed. Check your configuration and file permissions", 'red');
	}else{
		$CLI->_echo("Pre-flight check passed\t\t\t\t\tok", 'green');
	}

	return $error;
}
